/**
  *  \file client/wracelist.h
  *  \brief Color-keyed race list widget
  */
#ifndef PCC_V2_CLIENT_WRACELIST_H
#define PCC_V2_CLIENT_WRACELIST_H

#include "ui/ui.h"
#include "game/player.h"
#include "cpluslib/sigslot.h"

/** Color-keyed race list. Displays (a subrange of) all player names, each
    in his own color. Clicking a name emits a signal. Used for score charts. */
class WRaceList : public UIWidget {
    int preferred_width;     /**< Preferred width of the widget. */
    int from;                /**< First player to display (inclusive). */
    int to;                  /**< Last player to display (inclusive). */

    int current_click;       /**< Player the mouse is on (resp.\ last emitted signal). */

    GPlayerArray<GfxRect> positions;

    void calcLayout(GPlayerArray<GfxRect>& positions, int w);

 public:
    WRaceList(int preferred_width, int from, int to);

    void draw(GfxCanvas& can);

    void getLayoutInfo(LayoutInfo& info);

    bool handleEvent(const UIEvent& e, bool second_pass);

    /** Signals a player click.
        \param int player number */
    Signal1<int> sig_click;

    static const uint8 colors[];
};

#endif
