/**
  *  \file client/wtile.h
  *
  *  (c) 2001-2008 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WTILE_H
#define PCC_V2_CLIENT_WTILE_H

#include "ui/ui.h"
#include "gfx/gfx.h"
#include "ui/skin.h"

class WTile : public UIWidget {
    GfxPoint size;
    int      update_when;
    string_t heading;
    int      y_origin;
 public:
    enum State {
        sNormal,
        sHeadingOnly,
        sContentOnly
    };
 private:
    State state;
    void computeCoordinates();
 protected:
    virtual void drawFixed(GfxCanvas& can);
    virtual void drawData(GfxCanvas& can);
    /** Set text color. Shorthand for setting the color in the skin. */
    void setColor(UISkin::Color c)
        { getSkin().setColor(c); }
    /** Output text. Shorthand for UISkin::outText. In addition, this
        automatically does coordinate transformation. */
    void outText(GfxCanvas& can, int f, int x, int y, string_t text)
        { getSkin().outText(can, f, x + extent.x, y + extent.y + y_origin, text); }
    /** Output text. Shorthand for UISkin::outTextF. In addition, this
        automatically does coordinate transformation. */
    void outTextF(GfxCanvas& can, int f, int x, int y, int lim, string_t text)
        { getSkin().outTextF(can, f, x + extent.x, y + extent.y + y_origin, lim, text); }
    void drawBackground(GfxCanvas& can, GfxRect r);
    void addControl(UIGroup&, GfxRect r, UIWidget& w, bool rel_pos = false);

 public:
    WTile(GfxPoint size, int aid = 0, int awhen = 0);
    WTile(int wi, int he, int when = 0);
    void draw(GfxCanvas& can);
    void update();
    void update(int);
    void getLayoutInfo(LayoutInfo& info);
    bool handleEvent(const UIEvent& e, bool second_pass);

    void setDisplayState(State st);
    State getDisplayState() const
        { return state; }

    WTile& setHeading(string_t heading);
    const string_t getHeading() const
        { return heading; }

    virtual void addControls(UIGroup&, ObjectHolder&);
    GfxRect getInnerSize(int lmargin, int rmargin);
};

#endif
