/**
  *  \file tests/testfont.cc
  */

#include <iostream>
#include "gfx/font.h"
#include "io/streams.h"
#include "cpluslib/string.h"

int main(int argc, char** argv)
{
    while (*++argv) {
        try {
            Ptr<GfxFont> f = new GfxStdFont(Stream::openFileT(*argv, Stream::C_READ));

            int em = f->getTextWidth("m");
            
            std::cout << *argv << ":\n";
            std::cout << "  Height: " << f->getTextHeight("Tp") << "\n";
            std::cout << "  Em width: " << em << "\n";

            int count = 0, total = 0, max = 0, total_scaled = 0, count_scaled = 0;
            for (int i = 33; i < 126; ++i) {
                int now = f->getTextWidth(string_t(1, char(i)));
                if (now > max)
                    max = now;
                total += now;
                count++;

                int weight = (i >= 'a' && i <= 'z') ? 20
                           : (i >= 'A' && i <= 'Z') ? 5 : 1;
                total_scaled += weight*now;
                count_scaled += weight;
            }
            std::cout << "  Average character width: " << total/count
                      << " = " << (100*total)/(count*em) << "% em\n";
            std::cout << "  Adjusted character width: " << total_scaled/count_scaled
                      << " = " << (100*total_scaled)/(count_scaled*em) << "% em\n";
            std::cout << "  Maximum character width: " << max
                      << " = " << (100*max)/(em) << "% em\n";
        }
        catch (std::exception& e) {
            std::cerr << *argv << ": can't load: " << e.what() << "\n";
        }
    }
    return 0;
}
